@@ -26,7 +26,12 @@ def split_kw(string: str) -> tuple[str, str]:
 def parse_args() -> Args:
     """Cool git like multi command argument parser"""
     parser = ArgumentParser()
-    parser.add_argument("-v", action="store_true")
+    parser.add_argument("--verbose", "-v", action="store_true")
+    parser.add_argument("--host", type=str)
+    parser.add_argument("--username", "-u", type=str)
+    parser.add_argument("--password", "-p", type=str)
+
+    parser.add_argument("--timeout", "-t", type=int)
 
     subparsers = parser.add_subparsers(help="types of A")
     parser.set_defaults(func=fn_ui)
@@ -34,6 +39,9 @@ def parse_args() -> Args:
     parser_show = subparsers.add_parser("info")
     parser_show.set_defaults(func=fn_info)
 
+    parser_show = subparsers.add_parser("reboot")
+    parser_show.set_defaults(func=fn_reboot)
+
     parser_show = subparsers.add_parser("config-auth")
     parser_show.set_defaults(func=fn_config)
     parser_show.add_argument("kwargs", type=split_kw, nargs="+")
@@ -51,10 +59,21 @@ def parse_args() -> Args:
 
 def fn_info(_args: Args) -> None:
     """Entry point for info"""
-    for key, value in qrm_common.load_config_or_defaults():
+    print(f"Config file located at '{qrm_common.CFG_FILE}'")
+    for key, value in qrm_common.load_config_or_defaults().items():
         print(key, value)
 
 
+def fn_reboot(_args: Args) -> None:
+    """Entry point for info"""
+    try:
+        rm_ssh = qrm_common.ssh_connection(**qrm_common.load_config_or_defaults()["auth"])
+    except RuntimeError as exc:
+        print(f"Connection failed: {exc}")
+        return
+    qrm_common.reboot(rm_ssh)
+
+
 def fn_config(args: Args) -> None:
     """Entry point for configuration"""
     config = qrm_common.load_config_or_defaults()
@@ -78,7 +97,7 @@ def fn_upload(args: Args) -> None:
         qrm_common.upload_file(rm_ftp, path)
 
 
-def fn_list(_args: Args) -> None:
+def fn_list(_config: Args) -> None:
     """Entry point for content listing via CLI"""
     config = qrm_common.load_config_or_defaults()
     try:
@@ -100,7 +119,7 @@ def fn_list(_args: Args) -> None:
             print(f"{uid.split('-', 1)[0]}: {metadata['visibleName']} ({parent_str})")
 
 
-def fn_ui(_args: Args) -> None:
+def fn_ui(_config: Args) -> None:
     """Entry point for UI"""
 
     # pylint: disable=import-outside-toplevel (late import to allow headless operation)
@@ -111,4 +130,14 @@ def fn_ui(_args: Args) -> None:
 
 def main() -> None:
     """Entry point for everything else"""
-    (args := parse_args()).func(args)
+    config = qrm_common.load_config_or_defaults()
+    args = parse_args()
+    if args.host:
+        config["auth"]["host"] = args.host
+    if args.username:
+        config["auth"]["username"] = args.username
+    if args.password:
+        config["auth"]["password"] = args.password
+    if args.timeout is not None:
+        config["timeout"] = args.timeout
+    args.func(config)
