@@ -57,13 +57,13 @@ def save_config(data: Any) -> None:
     save_json(CFG_FILE, data)
 
 
-def ssh_connection(host: str, username: str, password=None) -> SSHClient:
+def ssh_connection(host: str, username: str, password:str|None=None, timeout:int=6) -> SSHClient:
     """Establishes and returns a paramiko SSH client session"""
     client = SSHClient()
     client.load_system_host_keys()
     try:
         print(f"Try to connect to {host!r}...")
-        client.connect(host, username=username, password=password)
+        client.connect(host, username=username, password=password, timeout=timeout)
         return client
     except socket.gaierror as exc:
         raise RuntimeError(f"{exc}") from exc
@@ -161,6 +161,9 @@ def upload_file(rm_sftp: SFTPClient, path: Path) -> None:
 
     # print(f"{time.time() - t}")
 
-    # rm_ssh.exec_command("/sbin/reboot")
-
     # print(f"{time.time() - t}")
+
+
+def reboot(client: SSHClient) -> None:
+    """Shortcut for rebooting the device"""
+    client.exec_command("/sbin/reboot")
