@@ -15,8 +15,9 @@ from PyQt5 import QtCore, QtGui, QtWidgets, uic
 from qrm import qrm_common
 
 
-def log():
-    return logging
+def log() -> logging.Logger:
+    """Returns the local logger"""
+    return logging.getLogger("qrm_ui")
 
 
 class RmConnectWindow(QtWidgets.QMainWindow):
@@ -39,6 +40,7 @@ class RmConnectWindow(QtWidgets.QMainWindow):
         self.txt_username.textChanged.connect(self.on_txt_username_textChanged)
         self.txt_password.textChanged.connect(self.on_txt_password_textChanged)
         self.pb_connect.clicked.connect(self.connect)
+        self.pb_reboot.clicked.connect(self.on_pb_reboot_clicked)
         self.pb_reboot.setEnabled(False)
 
         self.setGeometry(*self.config.get("window_geometry", (50, 50, 1000, 500)))
@@ -56,6 +58,9 @@ class RmConnectWindow(QtWidgets.QMainWindow):
         """React on password modification"""
         self.config["auth"]["password"] = text
 
+    def on_pb_reboot_clicked(bool) -> None:
+        """React on reboot button click"""
+
     @QtCore.pyqtSlot()
     def connect(self) -> None:
         """Connects to a reMarkable device via SSH and lists documents"""
@@ -115,26 +120,6 @@ class RmConnectWindow(QtWidgets.QMainWindow):
             QtCore.QEvent.KeyRelease,
             QtCore.QEvent.DragMove,
             QtCore.QEvent.DragLeave,
-            # QtCore.QEvent,
-            # QtGui.QMouseEvent,
-            QtGui.QPaintEvent,
-            # QtGui.QMoveEvent,
-            QtGui.QEnterEvent,
-            # QtGui.QResizeEvent,
-            # QtGui.QShowEvent,
-            # QtGui.QHelpEvent,
-            # QtCore.QChildEvent,
-            # QtCore.QDynamicPropertyChangeEvent,
-            QtGui.QHoverEvent,
-            QtGui.QPlatformSurfaceEvent,
-            # QtGui.QWindowStateChangeEvent,
-            QtGui.QKeyEvent,
-            # QtGui.QWheelEvent,
-            # QtGui.QFocusEvent,
-            QtGui.QHideEvent,
-            # QtGui.QCloseEvent,
-            # QtGui.QInputMethodQueryEvent,
-            # QtGui.QContextMenuEvent,
         }:
             # log().warn("unknown event: %r %r", event.type(), event)
             pass
